# Comment next line if not RC version
#define rcv     RC4

%define rel     1

Name:           klog
Version:        2.4.0
Release:        %mkrel %{?rcv: -c %{rcv}} %{rel}
Summary:        An amateur radio logging program
Group:          Communications/Radio
License:        GPLv3+
URL:            https://github.com/ea4k/klog
Source0:        https://github.com/ea4k/%{name}/archive/refs/tags/%{version}%{?rcv:-%{rcv}}/%{name}-%{version}%{?rcv:-%{rcv}}.tar.gz
Source1:        klog.desktop

%if ! %{defined rcv}
Patch0:         klog-2.2-fix-install.patch
%endif

Patch1:         klog-hamlib-4.6.0.patch

BuildRequires:  dos2unix
BuildRequires:  gettext
BuildRequires:  desktop-file-utils
BuildRequires:  imagemagick
BuildRequires:  pkgconfig(hamlib)
BuildRequires:  cmake(Qt6Charts)
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Help)
BuildRequires:  cmake(Qt6Location)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6Positioning)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6QuickWidgets)
BuildRequires:  cmake(Qt6SerialPort)
BuildRequires:  cmake(Qt6Sql)
# Don't include tests
#BuildRequires:  cmake(Qt6Test)
BuildRequires:  cmake(Qt6Widgets)

Requires:       qt6-qtlocation
Requires:       qt6-qtpositioning

Recommends:     trustedqsl

%description
KLog is an amateur radio logging program

Some features include:

    * DXCC award support.
    * Basic IOTA support.
    * Importing from Cabrillo files.
    * Importing from TLF.
    * Adding/Editing QSOs.
    * Save/read to/from disk file the log - ADIF format by default.
    * English/Spanish/Portuguese/Galician/Serbian/Swedish support.
    * QSL sent/received support.
    * Read/Write ADIF.
    * Delete QSOs.
    * DX-Cluster support.
    * WSJT-X integration.
    * Hamlib integration.
    * Export to QRZ.com, LOTW and Clublog.
    * New dark GUI mode since v1.7.
    * New maps feature.

Some features of this application are still under development.

%prep
%autosetup -p1 -n %{name}-%{version}%{?rcv:-%{rcv}}

# Remove anti Rusian-Ukranian war splash screen as inapropriate for Magaia's apolitical policy
sed -i 's:mw.showNotWar()::' %{!?rcv: src/}main.cpp

%build
%qmake_qt6 \
         "PREFIX=%{buildroot}%{_prefix}" \
         "CONFIG+=debug c++20" \
         %{!?rcv:src/src.pro}

%make_build

%install
%make_install

mv %{buildroot}%{_datadir}/%{name}/{COPYING,Changelog} .

# Install the provided desktop icon
for png in 48x48 64x64 128x128 256x256 512x512; do
  mkdir -p %{buildroot}%{_iconsdir}/hicolor/${png}/apps/
  convert -geometry $png %{!?rcv: src/}img/klog_512x512.png %{buildroot}%{_iconsdir}/hicolor/${png}/apps/%{name}.png
done

# Install the provided desktop file
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE1}

%files
%doc Changelog
%license COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%if ! %{defined rcv}
%doc README.md
%{_mandir}/man1/%{name}.1.*
%endif


%changelog
* Tue Apr 22 2025 daviddavid <daviddavid> 2.4.0-1.mga10
+ Revision: 2177993
- new version: 2.4.0
- switch to Qt6

* Sun Oct 20 2024 daviddavid <daviddavid> 2.3.4-2.mga10
+ Revision: 2108730
- add patch to fix build with hamlib >= 4.6.0

* Sun Mar 03 2024 barjac <barjac> 2.3.4-1.mga10
+ Revision: 2047249
- new version 2.3.4

* Sat Jan 13 2024 daviddavid <daviddavid> 2.3.3-1.mga10
+ Revision: 2030854
- new version: 2.3.3

* Wed Jun 28 2023 barjac <barjac> 2.3.2-1.mga9
+ Revision: 1963258
- new version 2.3.2
- fixes major bug stopping the program from starting for new installs

* Tue Jun 27 2023 barjac <barjac> 2.3.1-1.mga9
+ Revision: 1963230
- new version 2.3.1

* Mon Oct 24 2022 barjac <barjac> 2.3-1.mga9
+ Revision: 1898971
- new version 2.3
- adjust spec to also use upstream RC tarballs
+ papoteur <papoteur>
- new 2.2.1

* Sat Sep 03 2022 barjac <barjac> 2.2.1-1.mga9
+ Revision: 1883560
- new version 2.2.1
- re-diff patches
- patch to remove launch message

* Sat Apr 16 2022 barjac <barjac> 2.1-1.mga9
+ Revision: 1850773
- new version 2.1

* Wed Apr 06 2022 umeabot <umeabot> 1.9-2.mga9
+ Revision: 1846132
- Mageia 9 Mass Rebuild

* Sat Feb 19 2022 barjac <barjac> 1.9-1.mga9
+ Revision: 1781436
- new version 1.9
- new BuildRequires and Requires for new maps feature
- adjusted files list
- moved package from tools to sound and video to be
- compatible with other similar amateur radio packages

* Thu Feb 03 2022 barjac <barjac> 1.8.7-1.mga9
+ Revision: 1771173
- new version 1.8.7

* Sun Oct 17 2021 barjac <barjac> 1.8.5-1.mga9
+ Revision: 1751991
- restore patch (upstreamed but not yet implemented)
- new version 1.8.5
- drop obsolete patch

* Sun Aug 15 2021 barjac <barjac> 1.8-1.mga9
+ Revision: 1741531
- new version 1.8
- remove obsolete patch

* Wed Jun 23 2021 barjac <barjac> 1.6-1.mga9
+ Revision: 1732063
- new version 1.6
- Re diff FILPATHLEN (hamlib) patch
- New upstream Url

* Sun May 23 2021 barjac <barjac> 1.5.3-1.mga9
+ Revision: 1726186
- new version: 1.5.3
- bug fixes and new translation added

* Tue May 18 2021 barjac <barjac> 1.5.2-2.mga9
+ Revision: 1725302
- patch for hamlib-4.2 full release

* Sun May 09 2021 barjac <barjac> 1.5.2-1.mga9
+ Revision: 1722345
- new version 1.5.2

* Sat May 01 2021 barjac <barjac> 1.5.1-1.mga9
+ Revision: 1720659
- new version 1.5.1

* Thu Apr 08 2021 barjac <barjac> 1.5-1.mga9
+ Revision: 1714063
- new version 1.5
- re-diff install patch
- fix path to icons
- adjust files lists
- use src.pro
- minor changes to summary and description
- clean up some unneeded spec hacks
- recommend trustedqsl

* Sat Feb 06 2021 barjac <barjac> 1.4.7-1.mga8
+ Revision: 1674932
- new version 1.4.7
- updated Source0 now in github
- re-diffed install patch for 1.4.7
- minor addition to description

* Sat Dec 26 2020 daviddavid <daviddavid> 1.4.4-1.mga8
+ Revision: 1663778
- new version: 1.4.4

* Thu Dec 17 2020 umeabot <umeabot> 1.4.3-2.mga8
+ Revision: 1658765
- Rebuild for new Qt5

* Wed Dec 09 2020 daviddavid <daviddavid> 1.4.3-1.mga8
+ Revision: 1654778
- new version: 1.4.3

* Tue Dec 08 2020 daviddavid <daviddavid> 1.4.2-1.mga8
+ Revision: 1654730
- new version: 1.4.2

* Mon Dec 07 2020 barjac <barjac> 1.4-1.mga8
+ Revision: 1654312
- new version 1.4
- Edit spec to build RC versions

* Wed Oct 21 2020 daviddavid <daviddavid> 1.3.2-1.mga8
+ Revision: 1637549
- new version: 1.3.2

* Wed Oct 07 2020 daviddavid <daviddavid> 1.3.1-1.mga8
+ Revision: 1632516
- new version: 1.3.1

* Wed Sep 09 2020 barjac <barjac> 1.2.2-1.mga8
+ Revision: 1623742
- new version 1.2.2

* Tue Sep 01 2020 daviddavid <daviddavid> 1.2.1-1.mga8
+ Revision: 1620563
- new version: 1.2.1

* Tue Aug 18 2020 daviddavid <daviddavid> 1.2-1.mga8
+ Revision: 1614720
- new version: 1.2

* Mon May 04 2020 daviddavid <daviddavid> 1.1-1.mga8
+ Revision: 1578693
- new version: 1.1

* Fri Apr 17 2020 daviddavid <daviddavid> 1.0.1-1.mga8
+ Revision: 1567958
- new version: 1.0.1

* Wed Apr 01 2020 daviddavid <daviddavid> 1.0-1.mga8
+ Revision: 1562954
- new version: 1.0

* Thu Feb 20 2020 umeabot <umeabot> 0.9.9.1-2.mga8
+ Revision: 1546335
- Mageia 8 Mass Rebuild

* Sat Feb 01 2020 barjac <barjac> 0.9.9.1-1.mga8
+ Revision: 1486355
- rebuild for hamlib-4.0
- new version 0.9.9.1
- sync new upstream tarball(same version)

* Tue Jan 28 2020 barjac <barjac> 0.9.9-1.mga8
+ Revision: 1484209
- new version 0.9.9

* Mon Sep 02 2019 daviddavid <daviddavid> 0.9.8.1-1.mga8
+ Revision: 1436352
- new version: 0.9.8.1

* Tue Aug 20 2019 daviddavid <daviddavid> 0.9.8-1.mga8
+ Revision: 1430384
- new version: 0.9.8

* Sat Mar 30 2019 umeabot <umeabot> 0.9.7.2-2.mga7
+ Revision: 1382602
- Qt5 Rebuild

* Thu Mar 21 2019 daviddavid <daviddavid> 0.9.7.2-1.mga7
+ Revision: 1379359
- new version: 0.9.7.2

* Thu Mar 14 2019 daviddavid <daviddavid> 0.9.7.1-1.mga7
+ Revision: 1376070
- new version: 0.9.7.1

* Thu Mar 07 2019 daviddavid <daviddavid> 0.9.7-1.mga7
+ Revision: 1372180
- new version: 0.9.7

* Thu Dec 27 2018 daviddavid <daviddavid> 0.9.6-1.mga7
+ Revision: 1345215
- new version: 0.9.6

* Wed Oct 31 2018 daviddavid <daviddavid> 0.9.5-1.mga7
+ Revision: 1326829
- new version: 0.9.5

* Thu Aug 30 2018 daviddavid <daviddavid> 0.9.4.1-1.mga7
+ Revision: 1255703
- new version: 0.9.4.1

* Wed Apr 04 2018 daviddavid <daviddavid> 0.9.3-1.mga7
+ Revision: 1215131
- new version: 0.9.3

* Sun Feb 04 2018 daviddavid <daviddavid> 0.9.2.9-1.mga7
+ Revision: 1198855
- initial package klog

